==> google-cloud-contentwarehouse-0.1.0.tar.gz: google-cloud-contentwarehouse-0.1.0/google/cloud/contentwarehouse_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .async_document_service_request import (
    CreateDocumentMetadata,
    UpdateDocumentMetadata,
)
from .common import (
    AccessControlMode,
    DatabaseType,
    MergeFieldsOptions,
    RequestMetadata,
    ResponseMetadata,
    UpdateOptions,
    UpdateType,
    UserInfo,
)
from .document import (
    DateTimeArray,
    Document,
    DocumentReference,
    EnumArray,
    EnumValue,
    FloatArray,
    IntegerArray,
    MapProperty,
    Property,
    PropertyArray,
    RawDocumentFileType,
    TextArray,
    TimestampArray,
    TimestampValue,
    Value,
)
from .document_link_service import (
    CreateDocumentLinkRequest,
    DeleteDocumentLinkRequest,
    DocumentLink,
    ListLinkedSourcesRequest,
    ListLinkedSourcesResponse,
    ListLinkedTargetsRequest,
    ListLinkedTargetsResponse,
)
from .document_schema import (
    DateTimeTypeOptions,
    DocumentSchema,
    EnumTypeOptions,
    FloatTypeOptions,
    IntegerTypeOptions,
    MapTypeOptions,
    PropertyDefinition,
    PropertyTypeOptions,
    TextTypeOptions,
    TimestampTypeOptions,
)
from .document_schema_service import (
    CreateDocumentSchemaRequest,
    DeleteDocumentSchemaRequest,
    GetDocumentSchemaRequest,
    ListDocumentSchemasRequest,
    ListDocumentSchemasResponse,
    UpdateDocumentSchemaRequest,
)
from .document_service import (
    CreateDocumentResponse,
    FetchAclResponse,
    QAResult,
    SearchDocumentsResponse,
    SetAclResponse,
    UpdateDocumentResponse,
)
from .document_service_request import (
    CloudAIDocumentOption,
    CreateDocumentRequest,
    DeleteDocumentRequest,
    FetchAclRequest,
    GetDocumentRequest,
    SearchDocumentsRequest,
    SetAclRequest,
    UpdateDocumentRequest,
)
from .filters import DocumentQuery, FileTypeFilter, PropertyFilter, TimeFilter
from .histogram import (
    HistogramQuery,
    HistogramQueryPropertyNameFilter,
    HistogramQueryResult,
)
from .rule_engine import (
    AccessControlAction,
    Action,
    ActionExecutorOutput,
    ActionOutput,
    AddToFolderAction,
    DataUpdateAction,
    DataValidationAction,
    DeleteDocumentAction,
    InvalidRule,
    PublishAction,
    RemoveFromFolderAction,
    Rule,
    RuleActionsPair,
    RuleEngineOutput,
    RuleEvaluatorOutput,
    RuleSet,
)
from .ruleset_service_request import (
    CreateRuleSetRequest,
    DeleteRuleSetRequest,
    GetRuleSetRequest,
    ListRuleSetsRequest,
    ListRuleSetsResponse,
    UpdateRuleSetRequest,
)
from .synonymset import SynonymSet
from .synonymset_service_request import (
    CreateSynonymSetRequest,
    DeleteSynonymSetRequest,
    GetSynonymSetRequest,
    ListSynonymSetsRequest,
    ListSynonymSetsResponse,
    UpdateSynonymSetRequest,
)

__all__ = (
    "CreateDocumentMetadata",
    "UpdateDocumentMetadata",
    "MergeFieldsOptions",
    "RequestMetadata",
    "ResponseMetadata",
    "UpdateOptions",
    "UserInfo",
    "AccessControlMode",
    "DatabaseType",
    "UpdateType",
    "DateTimeArray",
    "Document",
    "DocumentReference",
    "EnumArray",
    "EnumValue",
    "FloatArray",
    "IntegerArray",
    "MapProperty",
    "Property",
    "PropertyArray",
    "TextArray",
    "TimestampArray",
    "TimestampValue",
    "Value",
    "RawDocumentFileType",
    "CreateDocumentLinkRequest",
    "DeleteDocumentLinkRequest",
    "DocumentLink",
    "ListLinkedSourcesRequest",
    "ListLinkedSourcesResponse",
    "ListLinkedTargetsRequest",
    "ListLinkedTargetsResponse",
    "DateTimeTypeOptions",
    "DocumentSchema",
    "EnumTypeOptions",
    "FloatTypeOptions",
    "IntegerTypeOptions",
    "MapTypeOptions",
    "PropertyDefinition",
    "PropertyTypeOptions",
    "TextTypeOptions",
    "TimestampTypeOptions",
    "CreateDocumentSchemaRequest",
    "DeleteDocumentSchemaRequest",
    "GetDocumentSchemaRequest",
    "ListDocumentSchemasRequest",
    "ListDocumentSchemasResponse",
    "UpdateDocumentSchemaRequest",
    "CreateDocumentResponse",
    "FetchAclResponse",
    "QAResult",
    "SearchDocumentsResponse",
    "SetAclResponse",
    "UpdateDocumentResponse",
    "CloudAIDocumentOption",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "FetchAclRequest",
    "GetDocumentRequest",
    "SearchDocumentsRequest",
    "SetAclRequest",
    "UpdateDocumentRequest",
    "DocumentQuery",
    "FileTypeFilter",
    "PropertyFilter",
    "TimeFilter",
    "HistogramQuery",
    "HistogramQueryPropertyNameFilter",
    "HistogramQueryResult",
    "AccessControlAction",
    "Action",
    "ActionExecutorOutput",
    "ActionOutput",
    "AddToFolderAction",
    "DataUpdateAction",
    "DataValidationAction",
    "DeleteDocumentAction",
    "InvalidRule",
    "PublishAction",
    "RemoveFromFolderAction",
    "Rule",
    "RuleActionsPair",
    "RuleEngineOutput",
    "RuleEvaluatorOutput",
    "RuleSet",
    "CreateRuleSetRequest",
    "DeleteRuleSetRequest",
    "GetRuleSetRequest",
    "ListRuleSetsRequest",
    "ListRuleSetsResponse",
    "UpdateRuleSetRequest",
    "SynonymSet",
    "CreateSynonymSetRequest",
    "DeleteSynonymSetRequest",
    "GetSynonymSetRequest",
    "ListSynonymSetsRequest",
    "ListSynonymSetsResponse",
    "UpdateSynonymSetRequest",
)

==> google-cloud-contentwarehouse-0.5.1.tar.gz: google-cloud-contentwarehouse-0.5.1/google/cloud/contentwarehouse_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .async_document_service_request import (
    CreateDocumentMetadata,
    UpdateDocumentMetadata,
)
from .common import (
    AccessControlMode,
    DatabaseType,
    DocumentCreatorDefaultRole,
    MergeFieldsOptions,
    RequestMetadata,
    ResponseMetadata,
    UpdateOptions,
    UpdateType,
    UserInfo,
)
from .document import (
    ContentCategory,
    DateTimeArray,
    Document,
    DocumentReference,
    EnumArray,
    EnumValue,
    FloatArray,
    IntegerArray,
    MapProperty,
    Property,
    PropertyArray,
    RawDocumentFileType,
    TextArray,
    TimestampArray,
    TimestampValue,
    Value,
)
from .document_link_service import (
    CreateDocumentLinkRequest,
    DeleteDocumentLinkRequest,
    DocumentLink,
    ListLinkedSourcesRequest,
    ListLinkedSourcesResponse,
    ListLinkedTargetsRequest,
    ListLinkedTargetsResponse,
)
from .document_schema import (
    DateTimeTypeOptions,
    DocumentSchema,
    EnumTypeOptions,
    FloatTypeOptions,
    IntegerTypeOptions,
    MapTypeOptions,
    PropertyDefinition,
    PropertyTypeOptions,
    TextTypeOptions,
    TimestampTypeOptions,
)
from .document_schema_service import (
    CreateDocumentSchemaRequest,
    DeleteDocumentSchemaRequest,
    GetDocumentSchemaRequest,
    ListDocumentSchemasRequest,
    ListDocumentSchemasResponse,
    UpdateDocumentSchemaRequest,
)
from .document_service import (
    CreateDocumentResponse,
    FetchAclResponse,
    QAResult,
    SearchDocumentsResponse,
    SetAclResponse,
    UpdateDocumentResponse,
)
from .document_service_request import (
    CloudAIDocumentOption,
    CreateDocumentRequest,
    DeleteDocumentRequest,
    FetchAclRequest,
    GetDocumentRequest,
    LockDocumentRequest,
    SearchDocumentsRequest,
    SetAclRequest,
    UpdateDocumentRequest,
)
from .filters import (
    CustomWeightsMetadata,
    DocumentQuery,
    FileTypeFilter,
    PropertyFilter,
    TimeFilter,
    WeightedSchemaProperty,
)
from .histogram import (
    HistogramQuery,
    HistogramQueryPropertyNameFilter,
    HistogramQueryResult,
)
from .rule_engine import (
    AccessControlAction,
    Action,
    ActionExecutorOutput,
    ActionOutput,
    AddToFolderAction,
    DataUpdateAction,
    DataValidationAction,
    DeleteDocumentAction,
    InvalidRule,
    PublishAction,
    RemoveFromFolderAction,
    Rule,
    RuleActionsPair,
    RuleEngineOutput,
    RuleEvaluatorOutput,
    RuleSet,
)
from .ruleset_service_request import (
    CreateRuleSetRequest,
    DeleteRuleSetRequest,
    GetRuleSetRequest,
    ListRuleSetsRequest,
    ListRuleSetsResponse,
    UpdateRuleSetRequest,
)
from .synonymset import SynonymSet
from .synonymset_service_request import (
    CreateSynonymSetRequest,
    DeleteSynonymSetRequest,
    GetSynonymSetRequest,
    ListSynonymSetsRequest,
    ListSynonymSetsResponse,
    UpdateSynonymSetRequest,
)

__all__ = (
    "CreateDocumentMetadata",
    "UpdateDocumentMetadata",
    "MergeFieldsOptions",
    "RequestMetadata",
    "ResponseMetadata",
    "UpdateOptions",
    "UserInfo",
    "AccessControlMode",
    "DatabaseType",
    "DocumentCreatorDefaultRole",
    "UpdateType",
    "DateTimeArray",
    "Document",
    "DocumentReference",
    "EnumArray",
    "EnumValue",
    "FloatArray",
    "IntegerArray",
    "MapProperty",
    "Property",
    "PropertyArray",
    "TextArray",
    "TimestampArray",
    "TimestampValue",
    "Value",
    "ContentCategory",
    "RawDocumentFileType",
    "CreateDocumentLinkRequest",
    "DeleteDocumentLinkRequest",
    "DocumentLink",
    "ListLinkedSourcesRequest",
    "ListLinkedSourcesResponse",
    "ListLinkedTargetsRequest",
    "ListLinkedTargetsResponse",
    "DateTimeTypeOptions",
    "DocumentSchema",
    "EnumTypeOptions",
    "FloatTypeOptions",
    "IntegerTypeOptions",
    "MapTypeOptions",
    "PropertyDefinition",
    "PropertyTypeOptions",
    "TextTypeOptions",
    "TimestampTypeOptions",
    "CreateDocumentSchemaRequest",
    "DeleteDocumentSchemaRequest",
    "GetDocumentSchemaRequest",
    "ListDocumentSchemasRequest",
    "ListDocumentSchemasResponse",
    "UpdateDocumentSchemaRequest",
    "CreateDocumentResponse",
    "FetchAclResponse",
    "QAResult",
    "SearchDocumentsResponse",
    "SetAclResponse",
    "UpdateDocumentResponse",
    "CloudAIDocumentOption",
    "CreateDocumentRequest",
    "DeleteDocumentRequest",
    "FetchAclRequest",
    "GetDocumentRequest",
    "LockDocumentRequest",
    "SearchDocumentsRequest",
    "SetAclRequest",
    "UpdateDocumentRequest",
    "CustomWeightsMetadata",
    "DocumentQuery",
    "FileTypeFilter",
    "PropertyFilter",
    "TimeFilter",
    "WeightedSchemaProperty",
    "HistogramQuery",
    "HistogramQueryPropertyNameFilter",
    "HistogramQueryResult",
    "AccessControlAction",
    "Action",
    "ActionExecutorOutput",
    "ActionOutput",
    "AddToFolderAction",
    "DataUpdateAction",
    "DataValidationAction",
    "DeleteDocumentAction",
    "InvalidRule",
    "PublishAction",
    "RemoveFromFolderAction",
    "Rule",
    "RuleActionsPair",
    "RuleEngineOutput",
    "RuleEvaluatorOutput",
    "RuleSet",
    "CreateRuleSetRequest",
    "DeleteRuleSetRequest",
    "GetRuleSetRequest",
    "ListRuleSetsRequest",
    "ListRuleSetsResponse",
    "UpdateRuleSetRequest",
    "SynonymSet",
    "CreateSynonymSetRequest",
    "DeleteSynonymSetRequest",
    "GetSynonymSetRequest",
    "ListSynonymSetsRequest",
    "ListSynonymSetsResponse",
    "UpdateSynonymSetRequest",
)
